#ifndef UMATH_H
#define UMATH_H

#include "lsqrms.h"

#include <math.h>

#if STDC_HEADERS
# include <float.h>
#endif

#define FABS(a) ((a) >= 0 ? (a) : (-a))
#define SQRTABS(a) ((a) >= 0 ? sqrt(a) : sqrt(-a))

#if defined(__EXTENSIONS__) && defined(_MIPS_FPSET) && (_MIPS_FPSET >= 32)
#  define LDBL long double
#  define DSQRTABS(a) ((a) >= 0 ? sqrtl(a) : sqrtl(-a))
#  define DSQRT(a) sqrtl(a)
#  define DSIN(a) sinl(a)
#  define DCOS(a) cosl(a)
#  define DACOS(a) acosl(a)
#  define DATAN(a) atanl(a)
#else
#  define LDBL double
#  define DSQRTABS(a) ((a) >= 0 ? sqrt(a) : sqrt(-a))
#  define DSQRT(a) sqrt(a)
#  define DSIN(a) sin(a)
#  define DCOS(a) cos(a)
#  define DACOS(a) acos(a)
#  define DATAN(a) atan(a)
#endif

#ifndef __sgi
#  define fsqrt(a) sqrt(a)
#endif

#define SQR(a) ((a)*(a))
#define DSQR(a) ((LDBL)(a)*(LDBL)(a))
#define CUBE(a) ((a)*(a)*(a))

#ifndef MIN
#  define MIN(a,b) (((a)<(b))?(a):(b))
#  define MAX(a,b) (((a)>(b))?(a):(b))
#endif

#ifdef DBL_EPSILON
# define epsilon DBL_EPSILON
#else
# ifdef __STDC__
#  define epsilon 1e-9
# else
#  define epsilon 1e-7
# endif
#endif

#endif /* ! defined(UMATH_H) */
